@@ -279,6 +279,12 @@ public Q_SLOTS:
     void switchBackRequested();
 
 Q_SIGNALS:
+    /**
+     * Emitted when a new tool is going to override the current tool
+     * @param canvas the currently active canvas.
+     */
+    void aboutToChangeTool(KoCanvasController *canvas);
+
     /**
      * Emitted when a new tool was selected or became active.
      * @param canvas the currently active canvas.
