@@ -542,6 +542,13 @@ public:
      */
     KisImportExportManager *importExportManager() const;
 
+    /**
+     * @brief serializeToNativeByteArray daves the document into a .kra file wtitten
+     * to a memory-based byte-array
+     * @return a byte array containing the .kra file
+     */
+    QByteArray serializeToNativeByteArray();
+
 public Q_SLOTS:
 
     /**
