@@ -28,6 +28,7 @@ Boston, MA 02110-1301, USA.
 #include <QUrl>
 
 #include "KisFilterGraph.h"
+#include "KisImportExportFilter.h"
 
 #include "kritaui_export.h"
 class KisFilterChain;
@@ -100,7 +101,7 @@ public:
      * and when the method returns @p mimeType contains this mimetype.
      * Oh, well, export is a C++ keyword ;)
      */
-    KisImportExportFilter::ConversionStatus exportDocument(const QString& location, QByteArray& mimeType);
+    KisImportExportFilter::ConversionStatus exportDocument(const QString& location, QByteArray& mimeType, KisPropertiesConfigurationSP exportConfiguration = 0);
 
     ///@name Static API
     //@{
@@ -112,6 +113,15 @@ public:
      */
     static QStringList mimeFilter(Direction direction);
 
+    /**
+     * @brief filterForMimeType loads the relevant import/export plugin and returns it. The caller
+     * is responsible for deleting it!
+     * @param mimetype the mimetype we want to import/export. If there's more than one plugin, the one
+     * with the highest weight as defined in the json description will be taken
+     * @param direction import or export
+     * @return a pointer to the filter plugin or 0 if none could be found
+     */
+    static KisImportExportFilter *filterForMimeType(const QString &mimetype, Direction direction);
 
     /**
      * Set the filter manager is batch mode (no dialog shown)
@@ -132,28 +142,43 @@ public:
      **/
     KoProgressUpdater *progressUpdater() const;
 
+    static QString askForAudioFileName(const QString &defaultDir, QWidget *parent);
+
 private:
     // === API for KisFilterChains === (internal)
     // The friend methods are private in KisFilterChain and
     // just forward calls to the methods here. Should be
     // pretty safe.
     friend QString KisFilterChain::filterManagerImportFile() const;
-    QString importFile() const {
+    QString importFile() const
+    {
         return m_importFileName;
     }
+
     friend QString KisFilterChain::filterManagerExportFile() const;
-    QString exportFile() const {
+    QString exportFile() const
+    {
         return m_exportFileName;
     }
+
     friend KisDocument *KisFilterChain::filterManagerKisDocument() const;
-    KisDocument *document() const {
+    KisDocument *document() const
+    {
         return m_document;
     }
+
     friend int KisFilterChain::filterManagerDirection() const;
-    int direction() const {
+    int direction() const
+    {
         return static_cast<int>(m_direction);
     }
 
+    friend KisPropertiesConfigurationSP KisFilterChain::filterManagerExportConfiguration() const;
+    KisPropertiesConfigurationSP exportConfiguration() const
+    {
+        return m_exportConfiguration;
+    }
+
     // Private API
     KisImportExportManager(const KisImportExportManager& rhs);
     KisImportExportManager &operator=(const KisImportExportManager& rhs);
@@ -168,6 +193,7 @@ private:
     QString m_exportFileName;
     CalligraFilter::Graph m_graph;
     Direction m_direction;
+    KisPropertiesConfigurationSP m_exportConfiguration;
 
     /// A static cache for the availability checks of filters
     static QStringList m_importMimeTypes;
